@@ -1,8 +1,9 @@
 from flask import session
 from flask.ext.babelpkg import Babel
-from flask.ext.appbuilder import translations
-from .views import LocaleView
 from ..basemanager import BaseManager
+from .. import translations
+from .views import LocaleView
+
 
 class BabelManager(BaseManager):
 
@@ -10,15 +11,15 @@ class BabelManager(BaseManager):
     babel_default_locale = ''
     locale_view = None
 
-    def __init__(self, baseapp):
-        super(BabelManager, self).__init__(baseapp)
-        self.babel = Babel(baseapp.get_app, translations)
-        self.babel_default_locale = self._get_default_locale(baseapp.get_app)
+    def __init__(self, appbuilder):
+        super(BabelManager, self).__init__(appbuilder)
+        self.babel = Babel(appbuilder.get_app, translations)
+        self.babel_default_locale = self._get_default_locale(appbuilder.get_app)
         self.babel.locale_selector_func = self.get_locale
 
     def register_views(self):
         self.locale_view = LocaleView()
-        self.baseapp.add_view_no_menu(self.locale_view)
+        self.appbuilder.add_view_no_menu(self.locale_view)
 
     @staticmethod
     def _get_default_locale(app):
