@@ -1,22 +1,27 @@
 import logging
 
-from flask_wtf import (Form, BooleanField, TextField,
-                       TextAreaField, IntegerField, FloatField, DateField, QuerySelectField,
-                       QuerySelectMultipleField)
+from flask_wtf import Form
+from wtforms import (BooleanField, TextField,
+                       TextAreaField, IntegerField, FloatField, DateField)
 
-from flask_wtf import validators
-from upload import (BS3FileUploadFieldWidget,
-                    BS3ImageUploadFieldWidget,
-                    FileUploadField,
-                    ImageUploadField)
-from validators import Unique
-from fieldwidgets import (BS3TextAreaFieldWidget,
+from wtforms.ext.sqlalchemy.fields import QuerySelectMultipleField, QuerySelectField
+
+from wtforms import validators
+#from flask_wtf import validators
+from .fieldwidgets import (BS3TextAreaFieldWidget,
                           BS3TextFieldWidget,
                           DatePickerWidget,
                           DateTimePickerWidget,
                           Select2Widget,
                           Select2ManyWidget)
 from .models.filters import Filters
+from .upload import (BS3FileUploadFieldWidget,
+                    BS3ImageUploadFieldWidget,
+                    FileUploadField,
+                    ImageUploadField)
+from .validators import Unique
+
+
 
 log = logging.getLogger(__name__)
 
