@@ -1,20 +1,16 @@
-import re
-import uuid
 import datetime
 import logging
 
-from sqlalchemy.ext.declarative import declared_attr
-from sqlalchemy import Table, Column, Integer, String, MetaData, ForeignKey, DateTime
+from sqlalchemy import Column, Integer, ForeignKey, DateTime
 from sqlalchemy.orm import relationship
 import sqlalchemy.types as types
-from sqlalchemy.types import String
+from sqlalchemy.ext.declarative import declared_attr
+
 from flask import g
 
 
 log = logging.getLogger(__name__)
 
-_camelcase_re = re.compile(r'([A-Z]+)(?=[a-z0-9])')
-
 
 class FileColumn(types.TypeDecorator):
     """
@@ -30,35 +26,7 @@ class ImageColumn(types.TypeDecorator):
     impl = types.Text
 
 
-class BaseMixin(object):
-    """
-        Use this class has a mixin for your models, it will define your tablenames automatically
-        MyModel will be called my_model on the database.
-        
-        ::
-        
-            from sqlalchemy import Table, Column, Integer, String, Boolean, ForeignKey, Date
-            from flask.ext.appbuilder import Base
-
-            class MyModel(BaseMixin, Base):
-                id = Column(Integer, primary_key=True)
-                name = Column(String(50), unique = True, nullable=False)
-
-    """
-    __table_args__ = {'extend_existing': True}
-
-    @declared_attr
-    def __tablename__(cls):
-        def _join(match):
-            word = match.group()
-            if len(word) > 1:
-                return ('_%s_%s' % (word[:-1], word[-1])).lower()
-            return '_' + word.lower()
-
-        return _camelcase_re.sub(_join, cls.__name__).lstrip('_')
-
-
-class AuditMixin(BaseMixin):
+class AuditMixin(object):
     """
         AuditMixin
         Mixin for models, adds 4 columns to stamp, time and user on creation and modification
@@ -100,3 +68,11 @@ class AuditMixin(BaseMixin):
         except Exception as e:
             #log.warning("AuditMixin Get User ID {0}".format(str(e)))
             return None
+
+
+"""
+    This is for retro compatibility
+"""
+class BaseMixin(object):
+    pass
+
