@@ -3,23 +3,20 @@ import logging
 
 from flask import g
 from flask_login import current_user
-from sqlalchemy import MetaData, Table
-from sqlalchemy.engine.reflection import Inspector
-from sqlalchemy.ext.declarative import declarative_base
 from werkzeug.security import generate_password_hash, check_password_hash
 from flask_login import LoginManager
 from flask_openid import OpenID
 from flask_babelpkg import lazy_gettext as _
+from sqlalchemy.engine.reflection import Inspector
 
-from flask_appbuilder import Base
-
-from .models import User, Role, PermissionView, Permission, ViewMenu, \
-    assoc_permissionview_role
-from .views import AuthDBView, AuthOIDView, ResetMyPasswordView, AuthLDAPView, \
-    ResetPasswordView, UserDBGeneralView, UserLDAPGeneralView, UserOIDGeneralView, RoleGeneralView, \
-    PermissionViewGeneralView, ViewMenuGeneralView, PermissionGeneralView, UserStatsChartView
+from .. import Base
 from ..basemanager import BaseManager
 
+from .models import User, Role, PermissionView, Permission, ViewMenu
+from .views import AuthDBView, AuthOIDView, ResetMyPasswordView, AuthLDAPView, \
+    ResetPasswordView, UserDBModelView, UserLDAPModelView, UserOIDModelView, RoleModelView, \
+    PermissionViewModelView, ViewMenuModelView, PermissionModelView, UserStatsChartView
+
 log = logging.getLogger(__name__)
 
 AUTH_OID = 0
@@ -44,17 +41,15 @@ class SecurityManager(BaseManager):
     lm = None
     oid = None
 
-    def __init__(self, baseapp):
+    def __init__(self, appbuilder):
         """
             SecurityManager contructor
-            param app:
-                The Flask app object
-            param session:
-                the database session for security tables, passed to BaseApp
-        """
-        super(SecurityManager, self).__init__(baseapp)
-        self.session = baseapp.get_session
-        app = self.baseapp.get_app
+            param appbuilder:
+                F.A.B AppBuilder main object
+            """
+        super(SecurityManager, self).__init__(appbuilder)
+        self.session = appbuilder.get_session
+        app = self.appbuilder.get_app
         self.auth_type = self._get_auth_type(app)
         self.auth_role_admin = self._get_auth_role_admin(app)
         self.auth_role_public = self._get_auth_role_public(app)
@@ -71,43 +66,43 @@ class SecurityManager(BaseManager):
         self.init_db()
 
     def register_views(self):
-        self.baseapp.add_view_no_menu(ResetPasswordView())
-        self.baseapp.add_view_no_menu(ResetMyPasswordView())
+        self.appbuilder.add_view_no_menu(ResetPasswordView())
+        self.appbuilder.add_view_no_menu(ResetMyPasswordView())
 
-        if self._get_auth_type(self.baseapp.get_app) == AUTH_DB:
-            self.user_view = UserDBGeneralView
+        if self._get_auth_type(self.appbuilder.get_app) == AUTH_DB:
+            self.user_view = UserDBModelView
             self.auth_view = AuthDBView()
-        elif self._get_auth_type(self.baseapp.get_app) == AUTH_LDAP:
-            self.user_view = UserLDAPGeneralView
+        elif self._get_auth_type(self.appbuilder.get_app) == AUTH_LDAP:
+            self.user_view = UserLDAPModelView
             self.auth_view = AuthLDAPView()
         else:
-            self.user_view = UserOIDGeneralView
+            self.user_view = UserOIDModelView
             self.auth_view = AuthOIDView()
             self.oid.after_login_func = self.auth_view.after_login
 
-        self.baseapp.add_view_no_menu(self.auth_view)
+        self.appbuilder.add_view_no_menu(self.auth_view)
 
-        self.user_view = self.baseapp.add_view(self.user_view, "List Users",
-                                      icon="fa-user", label=_("List Users"),
-                                      category="Security", category_icon="fa-cogs", category_label=_('Security'))
+        self.user_view = self.appbuilder.add_view(self.user_view, "List Users",
+                                                  icon="fa-user", label=_("List Users"),
+                                                  category="Security", category_icon="fa-cogs",
+                                                  category_label=_('Security'))
 
-
-        role_view = self.baseapp.add_view(RoleGeneralView, "List Roles", icon="fa-group", label=_('List Roles'),
-                              category="Security", category_icon="fa-cogs")
+        role_view = self.appbuilder.add_view(RoleModelView, "List Roles", icon="fa-group", label=_('List Roles'),
+                                             category="Security", category_icon="fa-cogs")
         role_view.related_views = [self.user_view.__class__]
-        self.baseapp.add_view(UserStatsChartView,
-                                      "User's Statistics", icon="fa-bar-chart-o", label=_("User's Statistics"),
-                                      category="Security")
-        self.baseapp.menu.add_separator("Security")
-        self.baseapp.add_view(PermissionGeneralView,
-                                      "Base Permissions", icon="fa-lock",
-                                      label=_("Base Permissions"), category="Security")
-        self.baseapp.add_view(ViewMenuGeneralView,
-                                      "Views/Menus", icon="fa-list-alt",
-                                      label=_('Views/Menus'), category="Security")
-        self.baseapp.add_view(PermissionViewGeneralView,
-                                      "Permission on Views/Menus", icon="fa-link",
-                                      label=_('Permission on Views/Menus'), category="Security")
+        self.appbuilder.add_view(UserStatsChartView,
+                                 "User's Statistics", icon="fa-bar-chart-o", label=_("User's Statistics"),
+                                 category="Security")
+        self.appbuilder.menu.add_separator("Security")
+        self.appbuilder.add_view(PermissionModelView,
+                                 "Base Permissions", icon="fa-lock",
+                                 label=_("Base Permissions"), category="Security")
+        self.appbuilder.add_view(ViewMenuModelView,
+                                 "Views/Menus", icon="fa-list-alt",
+                                 label=_('Views/Menus'), category="Security")
+        self.appbuilder.add_view(PermissionViewModelView,
+                                 "Permission on Views/Menus", icon="fa-link",
+                                 label=_('Permission on Views/Menus'), category="Security")
 
 
     def load_user(self, pk):
@@ -117,13 +112,39 @@ class SecurityManager(BaseManager):
     def before_request():
         g.user = current_user
 
+    def _migrate_db(self):
+        """
+            Migrate from 0.8 to 0.9, change GeneralView to ModelView
+            on ViewMenus
+        """
+        sec_view_prefixes = ['Permission', 'ViewMenu', 'PermissionView',
+                             'UserOID', 'UserLDAP', 'UserDB',
+                             'Role']
+        sec_view_old_sufix = 'GeneralView'
+        sec_view_new_sufix = 'ModelView'
+        for sec_view_prefix in sec_view_prefixes:
+            sec_view = self._find_view_menu('{0}{1}'.format(sec_view_prefix, sec_view_old_sufix))
+            if sec_view:
+                try:
+                    log.info("Migrate from 0.8 to 0.9 Changing {0}{1}".format(sec_view_prefix, sec_view_old_sufix))
+                    sec_view.name = '{0}{1}'.format(sec_view_prefix, sec_view_new_sufix)
+                    self.session.merge(sec_view)
+                    self.session.commit()
+                except Exception as e:
+                    log.error("Update ViewMenu error: {0}".format(str(e)))
+                    self.session.rollback()
+
+
     def init_db(self):
         try:
             engine = self.session.get_bind(mapper=None, clause=None)
-
-            log.info("Security DB not found Creating")
-            Base.metadata.create_all(engine)
-            log.info("Security DB Created")
+            inspector = Inspector.from_engine(engine)
+            if 'ab_user' not in inspector.get_table_names():
+                log.info("Security DB not found Creating all Models from Base")
+                Base.metadata.create_all(engine)
+                log.info("Security DB Created")
+            else:
+                self._migrate_db()
             if not self.session.query(Role).filter_by(name=self.auth_role_admin).first():
                 role = Role()
                 role.name = self.auth_role_admin
@@ -472,10 +493,10 @@ class SecurityManager(BaseManager):
         try:
             self.session.add(pv)
             self.session.commit()
-            log.info("Added Permission View: %s" % (str(pv)))
+            log.info("Created Permission View: %s" % (str(pv)))
             return pv
         except Exception as e:
-            log.error("Add Permission to View Error: {0}".format(str(e)))
+            log.error("Creation of Permission View Error: {0}".format(str(e)))
             self.session.rollback()
 
 
@@ -491,7 +512,7 @@ class SecurityManager(BaseManager):
                 self._del_permission(pv.permission.name)
             log.info("Removed Permission View: %s" % (str(permission_name)))
         except Exception as e:
-            log.error("Del Permission from View Error: {0}".format(str(e)))
+            log.error("Remove Permission from View Error: {0}".format(str(e)))
             self.session.rollback()
 
 
@@ -543,7 +564,7 @@ class SecurityManager(BaseManager):
                 self.session.commit()
                 log.info("Removed Permission %s to role %s" % (str(perm_view), role.name))
             except Exception as e:
-                log.error("Del Permission to Role Error: {0}".format(str(e)))
+                log.error("Remove Permission to Role Error: {0}".format(str(e)))
                 self.session.rollback()
 
 
