@@ -12,7 +12,7 @@ from flask.ext.babelpkg import gettext, lazy_gettext
 from flask_login import login_user, logout_user
 
 from flask_appbuilder.models.datamodel import SQLAModel
-from flask_appbuilder.views import BaseView, GeneralView, SimpleFormView, expose
+from flask_appbuilder.views import BaseView, ModelView, SimpleFormView, expose
 from flask_appbuilder.charts.views import DirectChartView
 
 from ..fieldwidgets import BS3PasswordFieldWidget
@@ -25,7 +25,7 @@ from .decorators import has_access
 log = logging.getLogger(__name__)
 
 
-class PermissionGeneralView(GeneralView):
+class PermissionModelView(ModelView):
     route_base = '/permissions'
 
     datamodel = SQLAModel(Permission)
@@ -38,7 +38,7 @@ class PermissionGeneralView(GeneralView):
     label_columns = {'name': lazy_gettext('Name')}
 
 
-class ViewMenuGeneralView(GeneralView):
+class ViewMenuModelView(ModelView):
     route_base = '/viewmenus'
 
     datamodel = SQLAModel(ViewMenu)
@@ -51,7 +51,7 @@ class ViewMenuGeneralView(GeneralView):
     label_columns = {'name': lazy_gettext('Name')}
 
 
-class PermissionViewGeneralView(GeneralView):
+class PermissionViewModelView(ModelView):
     route_base = '/permissionviews'
 
     datamodel = SQLAModel(PermissionView)
@@ -80,7 +80,7 @@ class ResetMyPasswordView(SimpleFormView):
     message = lazy_gettext('Password Changed')
 
     def form_post(self, form):
-        self.baseapp.sm.reset_password(g.user.id, form.password.data)
+        self.appbuilder.sm.reset_password(g.user.id, form.password.data)
         flash(as_unicode(self.message), 'info')
 
 
@@ -99,11 +99,11 @@ class ResetPasswordView(SimpleFormView):
 
     def form_post(self, form):
         pk = request.args.get('pk')
-        self.baseapp.sm.reset_password(pk, form.password.data)
+        self.appbuilder.sm.reset_password(pk, form.password.data)
         flash(as_unicode(self.message), 'info')
 
 
-class UserGeneralView(GeneralView):
+class UserModelView(ModelView):
     route_base = '/users'
     datamodel = SQLAModel(User)
 
@@ -168,7 +168,7 @@ class UserGeneralView(GeneralView):
     user_info_title = lazy_gettext("Your user information")
 
 
-class UserOIDGeneralView(UserGeneralView):
+class UserOIDModelView(UserModelView):
     @expose('/userinfo/')
     @has_access
     def userinfo(self):
@@ -176,10 +176,10 @@ class UserOIDGeneralView(UserGeneralView):
         return render_template(self.show_template,
                                title=self.user_info_title,
                                widgets=widgets,
-                               baseapp=self.baseapp)
+                               appbuilder=self.appbuilder)
 
 
-class UserLDAPGeneralView(UserGeneralView):
+class UserLDAPModelView(UserModelView):
     @expose('/userinfo/')
     @has_access
     def userinfo(self):
@@ -187,10 +187,10 @@ class UserLDAPGeneralView(UserGeneralView):
         return render_template(self.show_template,
                                title=self.user_info_title,
                                widgets=widgets,
-                               baseapp=self.baseapp)
+                               appbuilder=self.appbuilder)
 
 
-class UserDBGeneralView(UserGeneralView):
+class UserDBModelView(UserModelView):
     add_form_extra_fields = {'password': PasswordField(lazy_gettext('Password'),
                                                        description=lazy_gettext(
                                                            'Please use a good password policy, this application does not check this for you'),
@@ -215,7 +215,7 @@ class UserDBGeneralView(UserGeneralView):
                                pk=pk,
                                title=self.show_title,
                                widgets=widgets,
-                               baseapp=self.baseapp,
+                               appbuilder=self.appbuilder,
                                related_views=self._related_views)
 
 
@@ -228,7 +228,7 @@ class UserDBGeneralView(UserGeneralView):
         return render_template(self.show_template,
                                title=self.user_info_title,
                                widgets=widgets,
-                               baseapp=self.baseapp,
+                               appbuilder=self.appbuilder,
         )
 
     @action('resetmypassword', lazy_gettext("Reset my password"), "", "fa-lock")
@@ -252,13 +252,13 @@ class UserDBGeneralView(UserGeneralView):
 class UserStatsChartView(DirectChartView):
     datamodel = SQLAModel(User)
     chart_title = lazy_gettext('User Statistics')
-    label_columns = UserGeneralView.label_columns
-    search_columns = UserGeneralView.search_columns
+    label_columns = UserModelView.label_columns
+    search_columns = UserModelView.search_columns
     direct_columns = {'Login Count': ('username', 'login_count'),
                       'Failed Login Count': ('username', 'fail_login_count')}
 
 
-class RoleGeneralView(GeneralView):
+class RoleModelView(ModelView):
     route_base = '/roles'
 
     datamodel = SQLAModel(Role)
@@ -290,7 +290,7 @@ class AuthView(BaseView):
     @expose('/logout/')
     def logout(self):
         logout_user()
-        return redirect(self.baseapp.get_url_for_index)
+        return redirect(self.appbuilder.get_url_for_index)
 
 
 class AuthDBView(AuthView):
@@ -302,16 +302,16 @@ class AuthDBView(AuthView):
             return redirect('/')
         form = LoginForm_db()
         if form.validate_on_submit():
-            user = self.baseapp.sm.auth_user_db(form.username.data, form.password.data)
+            user = self.appbuilder.sm.auth_user_db(form.username.data, form.password.data)
             if not user:
                 flash(as_unicode(self.invalid_login_message), 'warning')
-                return redirect(self.baseapp.get_url_for_login)
+                return redirect(self.appbuilder.get_url_for_login)
             login_user(user, remember=False)
-            return redirect(self.baseapp.get_url_for_index)
+            return redirect(self.appbuilder.get_url_for_index)
         return render_template(self.login_template,
                                title=self.title,
                                form=form,
-                               baseapp=self.baseapp)
+                               appbuilder=self.appbuilder)
 
 
 class AuthLDAPView(AuthView):
@@ -321,19 +321,19 @@ class AuthLDAPView(AuthView):
     @expose('/login/', methods=['GET', 'POST'])
     def login(self):
         if g.user is not None and g.user.is_authenticated():
-            return redirect(self.baseapp.get_url_for_index)
+            return redirect(self.appbuilder.get_url_for_index)
         form = LoginForm_db()
         if form.validate_on_submit():
-            user = self.baseapp.sm.auth_user_ldap(form.username.data, form.password.data)
+            user = self.appbuilder.sm.auth_user_ldap(form.username.data, form.password.data)
             if not user:
                 flash(as_unicode(self.invalid_login_message), 'warning')
-                return redirect(self.baseapp.get_url_for_login)
+                return redirect(self.appbuilder.get_url_for_login)
             login_user(user, remember=False)
-            return redirect(self.baseapp.get_url_for_index)
+            return redirect(self.appbuilder.get_url_for_index)
         return render_template(self.login_template,
                                title=self.title,
                                form=form,
-                               baseapp=self.baseapp)
+                               appbuilder=self.appbuilder)
 
 
 class AuthOIDView(AuthView):
@@ -342,18 +342,18 @@ class AuthOIDView(AuthView):
     @expose('/login/', methods=['GET', 'POST'])
     def login(self, flag=True):
         if flag:
-            self.oid_login_handler(self.login, self.baseapp.sm.oid)
+            self.oid_login_handler(self.login, self.appbuilder.sm.oid)
         if g.user is not None and g.user.is_authenticated():
             return redirect('/')
         form = LoginForm_oid()
         if form.validate_on_submit():
             session['remember_me'] = form.remember_me.data
-            return self.baseapp.sm.oid.try_login(form.openid.data, ask_for=['email'])
+            return self.appbuilder.sm.oid.try_login(form.openid.data, ask_for=['email'])
         return render_template(self.login_template,
                                title=self.title,
                                form=form,
-                               providers=self.baseapp.app.config['OPENID_PROVIDERS'],
-                               baseapp=self.baseapp
+                               providers=self.appbuilder.app.config['OPENID_PROVIDERS'],
+                               appbuilder=self.appbuilder
         )
 
     def oid_login_handler(self, f, oid):
@@ -374,7 +374,7 @@ class AuthOIDView(AuthView):
         if resp.email is None or resp.email == "":
             flash(as_unicode(self.invalid_login_message), 'warning')
             return redirect('appbuilder/general/security/login_oid.html')
-        user = self.baseapp.sm.auth_user_oid(resp.email)
+        user = self.appbuilder.sm.auth_user_oid(resp.email)
         if user is None:
             flash(as_unicode(self.invalid_login_message), 'warning')
             return redirect('appbuilder/general/security/login_oid.html')
@@ -384,7 +384,7 @@ class AuthOIDView(AuthView):
             session.pop('remember_me', None)
 
         login_user(user, remember=remember_me)
-        return redirect(self.baseapp.get_url_for_index)
+        return redirect(self.appbuilder.get_url_for_index)
 
 
 
