@@ -2,15 +2,19 @@ from nose.tools import eq_, ok_, raises
 import unittest
 import os
 import string
-from flask.ext.sqlalchemy import SQLAlchemy
+import random
+import datetime
 from sqlalchemy import Column, Integer, String, ForeignKey, Date
 from sqlalchemy.orm import relationship
-from flask.ext.appbuilder.models.mixins import BaseMixin
-from flask.ext.appbuilder import Base
+from flask.ext.appbuilder import Model, SQLA
 from flask_appbuilder.models.filters import FilterStartsWith, FilterEqual
+from flask_appbuilder.charts.views import ChartView, TimeChartView, DirectChartView
 
 import logging
 
+"""
+    Constant english display string from framework
+"""
 DEFAULT_INDEX_STRING = 'Welcome'
 INVALID_LOGIN_STRING = 'Invalid login'
 ACCESS_IS_DENIED = "Access is Denied"
@@ -23,19 +27,22 @@ DEFAULT_ADMIN_PASSWORD = 'general'
 log = logging.getLogger(__name__)
 
 
-class Model1(BaseMixin, Base):
+class Model1(Model):
     id = Column(Integer, primary_key=True)
     field_string = Column(String(50), unique=True, nullable=False)
     field_integer = Column(Integer())
+    field_float = Column(Integer())
     field_date = Column(Date())
 
     def __repr__(self):
         return self.field_string
 
 
-class Model2(BaseMixin, Base):
+class Model2(Model):
     id = Column(Integer, primary_key=True)
     field_string = Column(String(50), unique=True, nullable=False)
+    field_integer = Column(Integer())
+    field_date = Column(Date())
     group_id = Column(Integer, ForeignKey('model1.id'), nullable=False)
     group = relationship("Model1")
 
@@ -47,9 +54,9 @@ class FlaskTestCase(unittest.TestCase):
 
     def setUp(self):
         from flask import Flask
-        from flask.ext.appbuilder.baseapp import BaseApp
+        from flask.ext.appbuilder import AppBuilder
         from flask.ext.appbuilder.models.datamodel import SQLAModel
-        from flask.ext.appbuilder.views import GeneralView
+        from flask.ext.appbuilder.views import ModelView
 
         self.app = Flask(__name__)
         self.basedir = os.path.abspath(os.path.dirname(__file__))
@@ -58,35 +65,53 @@ class FlaskTestCase(unittest.TestCase):
         self.app.config['SECRET_KEY'] = 'thisismyscretkey'
         self.app.config['WTF_CSRF_ENABLED'] = False
 
-        self.db = SQLAlchemy(self.app)
+        self.db = SQLA(self.app)
+        self.appbuilder = AppBuilder(self.app, self.db.session)
 
-        class Model1View(GeneralView):
+        class Model1View(ModelView):
             datamodel = SQLAModel(Model1)
 
-        class Model2View(GeneralView):
+        class Model2View(ModelView):
             datamodel = SQLAModel(Model2)
             related_views = [Model1View]
 
-        class Model1Filtered1View(GeneralView):
+        class Model1Filtered1View(ModelView):
             datamodel = SQLAModel(Model1)
             base_filters = [['field_string', FilterStartsWith, 'a']]
 
-        class Model1Filtered2View(GeneralView):
-            datamodel = SQLAModel(Model1, self.db.session)
+        class Model1Filtered2View(ModelView):
+            datamodel = SQLAModel(Model1)
             base_filters = [['field_integer', FilterEqual, 0]]
 
+        class Model2ChartView(ChartView):
+            datamodel = SQLAModel(Model2)
+            chart_title = 'Test Model1 Chart'
+            group_by_columns = 'field_string'
 
-        self.baseapp = BaseApp(self.app, self.db)
-        self.baseapp.add_view(Model1View, "Model1")
-        self.baseapp.add_view(Model1Filtered1View, "Model1Filtered1")
-        self.baseapp.add_view(Model1Filtered2View, "Model1Filtered2")
+        class Model2TimeChartView(TimeChartView):
+            datamodel = SQLAModel(Model2)
+            chart_title = 'Test Model1 Chart'
+            group_by_columns = 'field_date'
 
-        self.baseapp.add_view(Model2View, "Model2")
-        self.baseapp.add_view(Model2View, "Model2 Add", href='/model2view/add')
+        class Model2DirectChartView(DirectChartView):
+            datamodel = SQLAModel(Model2)
+            chart_title = 'Test Model1 Chart'
+            direct_columns = {'stat1': ('group', 'field_integer')}
+
+
+        self.appbuilder.add_view(Model1View, "Model1")
+        self.appbuilder.add_view(Model1Filtered1View, "Model1Filtered1")
+        self.appbuilder.add_view(Model1Filtered2View, "Model1Filtered2")
+
+        self.appbuilder.add_view(Model2View, "Model2")
+        self.appbuilder.add_view(Model2View, "Model2 Add", href='/model2view/add')
+        self.appbuilder.add_view(Model2ChartView, "Model2 Chart")
+        self.appbuilder.add_view(Model2TimeChartView, "Model2 Time Chart")
+        self.appbuilder.add_view(Model2DirectChartView, "Model2 Direct Chart")
 
 
     def tearDown(self):
-        self.baseapp = None
+        self.appbuilder = None
         self.app = None
         self.db = None
         log.debug("TEAR DOWN")
@@ -112,12 +137,35 @@ class FlaskTestCase(unittest.TestCase):
             self.db.session.add(model)
             self.db.session.commit()
 
+    def insert_data2(self):
+        models1 = [Model1(field_string='G1'),
+                   Model1(field_string='G2'),
+                   Model1(field_string='G2')]
+        for model1 in models1:
+            try:
+                self.db.session.add(model1)
+                self.db.session.commit()
+                for x,i in zip(string.ascii_letters[:10], range(10)):
+                    model = Model2(field_string="%stest" % (x),
+                               field_integer=random.randint(1, 10),
+                               group = model1)
+                    year = random.choice(range(1900, 2012))
+                    month = random.choice(range(1, 12))
+                    day = random.choice(range(1, 28))
+                    model.field_date = datetime(year, month, day)
+
+                    self.db.session.add(model)
+                    self.db.session.commit()
+            except:
+                self.db.session.rollback()
+
+
 
     def test_fab_views(self):
         """
             Test views creation and registration
         """
-        eq_(len(self.baseapp.baseviews), 15)  # current minimal views are 11
+        eq_(len(self.appbuilder.baseviews), 18)  # current minimal views are 11
 
 
     def test_model_creation(self):
@@ -303,3 +351,18 @@ class FlaskTestCase(unittest.TestCase):
         data = rv.data.decode('utf-8')
         ok_('atest' in data)
         ok_('btest' not in data)
+
+    def test_charts_view(self):
+        """
+            Test Various Chart views
+        """
+        client = self.app.test_client()
+        self.login(client, DEFAULT_ADMIN_USER, DEFAULT_ADMIN_PASSWORD)
+        self.insert_data2()
+        rv = client.get('/model2chartview/chart/')
+        eq_(rv.status_code, 200)
+        rv = client.get('/model2timechartview/chart/')
+        eq_(rv.status_code, 200)
+        rv = client.get('/model2directchartview/chart/')
+        eq_(rv.status_code, 200)
+
